# UsePy

<a href="https://github.com/mic1on/usepy/actions/workflows/test.yml?query=event%3Apush+branch%3Amain" target="_blank">
    <img src="https://github.com/mic1on/usepy/workflows/test%20suite/badge.svg?branch=main&event=push" alt="Test">
</a>
<a href="https://pypi.org/project/usepy" target="_blank">
    <img src="https://img.shields.io/pypi/v/usepy.svg" alt="Package version">
</a>

<a href="https://pypi.org/project/usepy" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/usepy.svg" alt="Supported Python versions">
</a>

`usepy`是一个简单易用的Python工具库，包含了一些常用的工具函数。

### 安装

```bash
pip install usepy -U
```

### 示例及文档

[官方文档](https://usepy.code05.com/)